@@ -44,12 +44,15 @@ DEFUN_NEW("PROFILE",object,fSprofile,SI
 {				/* 2 args */
   
   object ar=sSAprofile_arrayA->s.s_dbind;
+  void *x;
+
   if (type_of(ar)!=t_string)
     FEerror("si:*Profile-array* not a string",0);
   if( type_of(start_address)!=t_fixnum ||   type_of(scale)!=t_fixnum)
     FEerror("Needs start address and scale as args",0);
 
-  profil(!(fix(start_address)*fix(scale)) ? NULL : (void *) (ar->ust.ust_self), (ar->ust.ust_dim),
+  x=!(fix(start_address)*fix(scale)) ? NULL : (void *) (ar->ust.ust_self);
+  profil(x, (ar->ust.ust_dim),
 	 fix(start_address),fix(scale) << 8);
   RETURN1(start_address);
 }
