@@ -676,6 +676,7 @@ mark_object(object x) {
     
   case t_cfdata:
     
+    mark_object(x->cfd.cfd_dlist);
     if (x->cfd.cfd_self != NULL)
       {int i=x->cfd.cfd_fillp;
       while(i-- > 0)
@@ -1423,7 +1424,8 @@ GBC(enum type t) {
 /* #endif */
       {holepage = 1;
       rb_limit=end+PAGESIZE;
-      rb_end=rb_limit+2*RB_GETA;}
+      rb_end=rb_limit+2*RB_GETA;
+      rb_end=rb_end>core_end ? core_end : rb_end;}
 /*       nrbpage = (rb_end-rb_start)/PAGESIZE;} */
     
     if (nrbpage < 0)
@@ -1508,8 +1510,6 @@ DEFUN_NEW("ROOM-REPORT",object,fSroom_report,SI
   int i;
   object x;
   
-  check_arg(0);
-  
   /*
     GBC(t_contiguous);
   */
