@@ -39,8 +39,7 @@ void Ldirectory ( void )
 				    path->pn.pn_directory,
 				    new->pn.pn_name,
 				    new->pn.pn_type,
-				    new->pn.pn_version,
-				    Cnil));
+				    new->pn.pn_version));
 	    }
 	  } while (FindNextFile(dirHandle,&data));
 	  FindClose(dirHandle);
@@ -53,3 +52,12 @@ void Ldirectory ( void )
 	}
 }
 
+int
+mingwlisten(FILE *fp) {
+
+  int c = 0;
+  ioctlsocket(fileno(fp), FIONREAD, &c);
+  if (c<=0)
+    return 1;
+  return 0;
+}
