@@ -705,7 +705,7 @@ number_times(object x, object y)
 	SHORTFLOAT:
 		z = alloc_object(t_shortfloat);
 		sf(z) = (shortfloat)(dx * dy);
-		if (!sf(z) && dx && dy) FLOATING_POINT_UNDERFLOW(sLA,list(2,x,y));
+		if (number_zerop(z) && dx && dy) FLOATING_POINT_UNDERFLOW(sLA,list(2,x,y));
 		if (!ISFINITE(sf(z)) && ISFINITE(dx) && ISFINITE(dy)) FLOATING_POINT_OVERFLOW(sLA,list(2,x,y));
 		return(z);
 
@@ -729,7 +729,7 @@ number_times(object x, object y)
 	LONGFLOAT:
 		z = alloc_object(t_longfloat);
 		lf(z) = dx * dy;
-		if (!lf(z) && dx && dy) FLOATING_POINT_UNDERFLOW(sLA,list(2,x,y));
+		if (number_zerop(z) && dx && dy) FLOATING_POINT_UNDERFLOW(sLA,list(2,x,y));
 		if (!ISFINITE(lf(z)) && ISFINITE(dx) && ISFINITE(dy)) FLOATING_POINT_OVERFLOW(sLA,list(2,x,y));
 		return(z);
 
