@@ -24,11 +24,43 @@ License for more details.
 
 #define IN_RUN_PROCESS
 #include "include.h"
+
+#ifdef HAVE_SYS_SOCKIO_H
+#include <sys/sockio.h>
+#endif
+
 #ifdef RUN_PROCESS
 
 void setup_stream_buffer(object);
 object make_two_way_stream(object, object);
 
+/* LISP - Lisp Wrapper for the "c" code.
+ *
+ * The lisp OBJECT is passed to the code and a string must be extracted
+ * and null terminated to make it work with the "C" code.
+ *
+ * Lisp Interface code.
+ */
+
+char *lisp_to_string(string)
+object string;
+{
+	int	i, len;
+	char	*sself;
+	char	*cstr;
+
+	len = string->st.st_fillp;
+
+	cstr = (char *) malloc (len+1);
+	sself = &(string->st.st_self[0]);
+	for (i=0; i<len; i++)
+	{
+		cstr[i] = sself[i];
+	}
+	cstr[i] = 0;
+	return (cstr);
+}
+
 #ifdef __MINGW32__
 
 #include<windows.h>
@@ -318,33 +350,6 @@ gcl_init_socket_function()
 
 
 
-/* LISP - Lisp Wrapper for the "c" code.
- *
- * The lisp OBJECT is passed to the code and a string must be extracted
- * and null terminated to make it work with the "C" code.
- *
- * Lisp Interface code.
- */
-
-static char *lisp_to_string(string)
-object string;
-{
-	int	i, len;
-	char	*sself;
-	char	*cstr;
-
-	len = string->st.st_fillp;
-
-	cstr = (char *) malloc (len+1);
-	sself = &(string->st.st_self[0]);
-	for (i=0; i<len; i++)
-	{
-		cstr[i] = sself[i];
-	}
-	cstr[i] = 0;
-	return (cstr);
-}
-
 /* open_connection - Open_Connection a socket to a server that you know by port number.
  *
  * The caller must know the number of the service and and name of the
@@ -463,7 +468,7 @@ FFN(siLmake_socket_stream)()
 {
   check_arg(2);
   vs_base[0] = make_socket_stream(vs_base[0], vs_base[1]);
-  vs_pop;
+  vs_popp;
 }
 
 /*
