@@ -55,7 +55,7 @@ FFN(Fdefun)(object args)
 	    object x;
 	    vs_base = vs_top;
 	    x=alloc_object(t_ifun);
-	    x->ifn.ifn_self=MMcons(sLlambda, MMcdr(args));
+	    x->ifn.ifn_self=list(3,sLlambda,MMcadr(args),listA(3,sLblock,MMcadr(name),MMcddr(args)));
 	    vs_push(x);
 	    putprop(MMcadr(name),vs_base[0],sSsetf_function);
 	    vs_base[0]=name;
@@ -72,8 +72,7 @@ FFN(Fdefun)(object args)
 	}
 	if (name->s.s_hpack == lisp_package &&
 	    name->s.s_gfdef != OBJNULL && initflag) {
-	  vs_push(make_simple_string(
-				     "~S is being redefined."));
+	  vs_push(make_simple_string("~S is being redefined."));
 	  ifuncall2(sLwarn, vs_head, name);
 	  vs_popp;
 	}
@@ -207,15 +206,20 @@ FFN(Fthe)(object args)
 	args = MMcar(args);
 	if (consp(args) && MMcar(args) == sLvalues) {
 	  vs = vs_base;
-	  for (args=MMcdr(args); !endp(args) && vs<vs_top; args=MMcdr(args), vs++)
-	    /*			{ if (vs >= vs_top)
-				FEerror("Too many return values.", 0);*/
-	    if (ifuncall2(sLtypep, *vs, MMcar(args)) == Cnil)
+	  for (args=MMcdr(args); !endp(args) && vs<vs_top; args=MMcdr(args), vs++) {
+	    if (MMcar(args)==ANDrest) {
+	      for (args=MMcdr(args);vs<vs_top;vs++)
+		if (ifuncall2(sLtypep, *vs, MMcar(args)) == Cnil)
+		  FEwrong_type_argument(MMcar(args), *vs);
+	    } else if (MMcar(args)==ANDoptional)
+	      vs--;
+	    else if (ifuncall2(sLtypep, *vs, MMcar(args)) == Cnil)
 	      FEwrong_type_argument(MMcar(args), *vs);
+	  }
 	  /*}
 		if (vs < vs_top)
 			FEerror("Too few return values.", 0);*/
-	  for (args=MMcdr(args); !endp(args); args=MMcdr(args))
+	  for (; !endp(args) && MMcar(args)!=ANDrest && MMcar(args)!=ANDoptional; args=MMcdr(args))
 	    if (ifuncall2(sLtypep, Cnil, MMcar(args)) == Cnil)
 	      FEwrong_type_argument(MMcar(args), Cnil);
 	  
