@@ -467,7 +467,7 @@ and load your system with:
 (defun operation-transformations (name mode &optional arg)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
-    (let ((*system-directory* (funcall (the function (car system))))
+    (let ((*system-directory* (funcall (car system))) ;(the function (car system))
 	  (modules (cadr system)))
       (ecase mode
 	(:compile
@@ -536,18 +536,17 @@ and load your system with:
 
 #+cmu17
 (defparameter *byte-files* '(defclass defcombin iterate env))
-
 (defun operate-on-system (name mode &optional arg print-only)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
-    (let* ((*system-directory* (funcall (the function (car system))))
+    (let* ((*system-directory* (funcall (car system))) ; (the function (car system))
 	   (transformations (operation-transformations name mode arg)))
       (labels ((load-binary (name pathname)
 		 (format t "~&Loading binary of ~A...~%" name)
 		 (or print-only (load pathname)))	       
 	       (load-module (m)
 		 (let* ((name (module-name m))
-			(*load-verbose* nil)
+			(*load-verbose* t)
 			(binary (make-binary-pathname m)))
 		   (load-binary name binary)))
 	       (compile-module (m)
@@ -600,9 +599,11 @@ and load your system with:
 				(:source (car *system-directory*))
 				(:binary (cdr *system-directory*)))))))
 	 (dir (pathname-directory directory))
-	 (ldir (if (consp dir)
-		   dir
-		   (pathname-directory (truename directory))))
+	 (ldir nil)
+
+;	 (if (consp dir)
+;		   dir
+;		   (pathname-directory (truename directory))))
 
 	 (port-dname (when (and port 
 				(or *put-impl-binaries-in-impl-directory-p*
@@ -612,10 +613,20 @@ and load your system with:
 			     (append ldir (list "impl" port-dname))
 			     ldir))
 			     
+;	 (port-directory (if port-dname
+;			     (append ldir (list "impl" port-dname))
+;			     ldir))
+			     
+	 (port-directory ldir)
+	 (port-device (if (null port-directory)
+			  nil
+			(pathname-device port-directory)))
+			     
          (pathname
            (make-pathname
              :name (string-downcase (string name))
              :type extension
+	     :device port-device
 	     :directory port-directory
              :defaults directory)))
 
@@ -628,14 +639,14 @@ and load your system with:
 (defun system-source-files (name)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
-    (let ((*system-directory* (funcall (the function (car system))))
+    (let ((*system-directory* (funcall (car system))) ;(the function (car system))
 	  (modules (cadr system)))
       (mapcar #'make-source-pathname modules))))
 
 (defun system-binary-files (name)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
-    (let ((*system-directory* (funcall (the function (car system))))
+    (let ((*system-directory* (funcall (car system))) ;(the function (car system))
 	  (modules (cadr system)))
       (mapcar #'make-binary-pathname modules))))
 
@@ -728,58 +739,58 @@ and load your system with:
    (ibcl-patches    t            t            ()                ibcl)
    (gold-patches    t            t            ()                gclisp)
    
-   (pcl_pkg         t            t            ())
+   (gcl_pcl_pkg         t            t            ())
    (sys-proclaim    t            t            ()                kcl)
-   (pcl_walk        (pcl_pkg)    (pcl_pkg)    ())
-   (pcl_iterate     t            t            ())
-   (pcl_macros      t            t            ())
-   (pcl_low         (pcl_pkg pcl_macros) t            (pcl_macros))
+   (gcl_pcl_walk        (gcl_pcl_pkg)    (gcl_pcl_pkg)    ())
+   (gcl_pcl_iterate     t            t            ())
+   (gcl_pcl_macros    t         t        ())
+   (gcl_pcl_low         (gcl_pcl_pkg gcl_pcl_macros) t            (gcl_pcl_macros))
    
    
-   (genera-low     (pcl_low)         (pcl_low)        (pcl_low)            Genera)
-   (cloe-low	   (pcl_low)	     (pcl_low)	      (pcl_low)            Cloe)
-   (lucid-low      (pcl_low)         (pcl_low)        (pcl_low)            Lucid)
-   (Xerox-low      (pcl_low)         (pcl_low)        (pcl_low)            Xerox)
-   (ti-low         (pcl_low)         (pcl_low)        (pcl_low)            TI)
-   (vaxl-low       (pcl_low)         (pcl_low)        (pcl_low)            vaxlisp)
-   (kcl-low        (pcl_low)         (pcl_low)        (pcl_low)            KCL)
-   (ibcl-low       (pcl_low)         (pcl_low)        (pcl_low)            IBCL)
-   (pcl_gcl_low    (pcl_low)         (pcl_low)        (pcl_low)            gcl)
-   (excl-low       (pcl_low)         (pcl_low)        (pcl_low)            excl)
-   (cmu-low        (pcl_low)         (pcl_low)        (pcl_low)            CMU)
-   (hp-low         (pcl_low)         (pcl_low)        (pcl_low)            HP-HPLabs)
-   (gold-low       (pcl_low)         (pcl_low)        (pcl_low)            gclisp) 
-   (pyr-low        (pcl_low)         (pcl_low)        (pcl_low)            pyramid) 
-   (coral-low      (pcl_low)         (pcl_low)        (pcl_low)            coral)
+   (genera-low     (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            Genera)
+   (cloe-low	   (gcl_pcl_low)	     (gcl_pcl_low)	      (gcl_pcl_low)            Cloe)
+   (lucid-low      (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            Lucid)
+   (Xerox-low      (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            Xerox)
+   (ti-low         (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            TI)
+   (vaxl-low       (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            vaxlisp)
+   (kcl-low        (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            KCL)
+   (ibcl-low       (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            IBCL)
+   (gcl_pcl_impl_low    (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            gcl)
+   (excl-low       (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            excl)
+   (cmu-low        (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            CMU)
+   (hp-low         (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            HP-HPLabs)
+   (gold-low       (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            gclisp) 
+   (pyr-low        (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            pyramid) 
+   (coral-low      (gcl_pcl_low)         (gcl_pcl_low)        (gcl_pcl_low)            coral)
    
-   (pcl_fin         t                                   t (pcl_low))
-   (pcl_defclass    t                                   t (pcl_low))
-   (pcl_defs        t                                   t (pcl_defclass pcl_macros pcl_iterate))
-   (pcl_fngen       t                                   t (pcl_low))
-   (pcl_cache       t                                   t (pcl_low pcl_defs))
-   (pcl_dlisp       t                                   t (pcl_defs pcl_low pcl_fin pcl_cache))
-   (pcl_dlisp2      t                                   t (pcl_low pcl_fin pcl_cache pcl_dlisp))
-   (pcl_boot        t                                   t (pcl_defs pcl_fin))
-   (pcl_vector      t                                   t (pcl_boot pcl_defs pcl_cache pcl_fin))
-   (pcl_slots_boot  t                                   t (pcl_vector pcl_boot pcl_defs pcl_cache pcl_fin))
-   (pcl_combin      t                                   t (pcl_boot pcl_defs))
-   (pcl_dfun        t                                   t (pcl_boot pcl_low pcl_cache))
-   (pcl_fast_init   t                                   t (pcl_boot pcl_low))
-   (pcl_braid       (+ pcl_precom1 pcl_precom2)         t (pcl_boot pcl_defs pcl_low pcl_fin pcl_cache))
-   (pcl_generic_functions t                             t (pcl_boot))
-   (pcl_slots       t                                   t (pcl_vector pcl_boot pcl_defs pcl_low pcl_cache pcl_fin))
-   (pcl_init        t                                   t (pcl_vector pcl_boot pcl_defs pcl_low pcl_fast_init))
-   (pcl_std_class   t                                   t (pcl_vector pcl_boot pcl_defs pcl_low pcl_cache pcl_fin pcl_slots))
-   (pcl_cpl         t                                   t (pcl_vector pcl_boot pcl_defs pcl_low pcl_cache pcl_fin pcl_slots))
-   (pcl_fsc         t                                   t (pcl_defclass pcl_boot pcl_defs pcl_low pcl_fin pcl_cache))
-   (pcl_methods     t                                   t (pcl_defclass pcl_boot pcl_defs pcl_low pcl_fin pcl_cache))
-   (pcl_fixup       t                                   t (pcl_boot pcl_defs pcl_low pcl_fin))
-   (pcl_defcombin   t                                   t (pcl_defclass pcl_boot pcl_defs pcl_low pcl_fin))
-   (pcl_ctypes      t                                   t (pcl_defclass pcl_defcombin))
-   (pcl_env         t                                   t (pcl_defclass pcl_boot pcl_defs pcl_low pcl_fin))
-   (pcl_compat      t                                   t ())
-   (pcl_precom1     (pcl_dlisp)                         t (pcl_defs pcl_low pcl_cache pcl_fin pcl_dfun))
-   (pcl_precom2     (pcl_dlisp)                         t (pcl_defs pcl_low pcl_cache pcl_fin pcl_dfun))
+   (gcl_pcl_fin         t                                   t (gcl_pcl_low))
+   (gcl_pcl_defclass    t                                   t (gcl_pcl_low))
+   (gcl_pcl_defs        t                                   t (gcl_pcl_defclass gcl_pcl_macros gcl_pcl_iterate))
+   (gcl_pcl_fngen       t                                   t (gcl_pcl_low))
+   (gcl_pcl_cache       t                                   t (gcl_pcl_low gcl_pcl_defs))
+   (gcl_pcl_dlisp       t                                   t (gcl_pcl_defs gcl_pcl_low gcl_pcl_fin gcl_pcl_cache))
+   (gcl_pcl_dlisp2      t                                   t (gcl_pcl_low gcl_pcl_fin gcl_pcl_cache gcl_pcl_dlisp))
+   (gcl_pcl_boot        t                                   t (gcl_pcl_defs gcl_pcl_fin))
+   (gcl_pcl_vector      t                                   t (gcl_pcl_boot gcl_pcl_defs gcl_pcl_cache gcl_pcl_fin))
+   (gcl_pcl_slots_boot  t                                   t (gcl_pcl_vector gcl_pcl_boot gcl_pcl_defs gcl_pcl_cache gcl_pcl_fin))
+   (gcl_pcl_combin      t                                   t (gcl_pcl_boot gcl_pcl_defs))
+   (gcl_pcl_dfun        t                                   t (gcl_pcl_boot gcl_pcl_low gcl_pcl_cache))
+   (gcl_pcl_fast_init   t                                   t (gcl_pcl_boot gcl_pcl_low))
+   (gcl_pcl_braid       (+ gcl_pcl_precom1 gcl_pcl_precom2)         t (gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin gcl_pcl_cache))
+   (gcl_pcl_generic_functions t                             t (gcl_pcl_boot))
+   (gcl_pcl_slots       t                                   t (gcl_pcl_vector gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_cache gcl_pcl_fin))
+   (gcl_pcl_init        t                                   t (gcl_pcl_vector gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fast_init))
+   (gcl_pcl_std_class   t                                   t (gcl_pcl_vector gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_cache gcl_pcl_fin gcl_pcl_slots))
+   (gcl_pcl_cpl         t                                   t (gcl_pcl_vector gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_cache gcl_pcl_fin gcl_pcl_slots))
+   (gcl_pcl_fsc         t                                   t (gcl_pcl_defclass gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin gcl_pcl_cache))
+   (gcl_pcl_methods     t                                   t (gcl_pcl_defclass gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin gcl_pcl_cache))
+   (gcl_pcl_fixup       t                                   t (gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin))
+   (gcl_pcl_defcombin   t                                   t (gcl_pcl_defclass gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin))
+   (gcl_pcl_ctypes      t                                   t (gcl_pcl_defclass gcl_pcl_defcombin))
+   (gcl_pcl_env         t                                   t (gcl_pcl_defclass gcl_pcl_boot gcl_pcl_defs gcl_pcl_low gcl_pcl_fin))
+   (gcl_pcl_compat      t                                   t ())
+   (gcl_pcl_precom1     (gcl_pcl_dlisp)                         t (gcl_pcl_defs gcl_pcl_low gcl_pcl_cache gcl_pcl_fin gcl_pcl_dfun))
+   (gcl_pcl_precom2     (gcl_pcl_dlisp)                         t (gcl_pcl_defs gcl_pcl_low gcl_pcl_cache gcl_pcl_fin gcl_pcl_dfun))
    ))
 
 (defun compile-pcl (&optional m)
